@@ -143,7 +143,7 @@ function addTestCaseToTestplanDialog() {
 function addTestCaseToPlan(tcId, tcatId) {
 	(function($) {
 		$(function() {
-			var planid = $("input[@name=selected_planid]:checked").val();
+			var planid = $("input[name='selected_planid']:checked").val();
 			
 			if (planid && planid != '') {
 				var url = baseLocation+"/testcreate?type=testcaseinplan&tcatId="+tcatId+"&tcId="+tcId+"&planid="+planid;
@@ -193,7 +193,7 @@ function creaTicket(tcName, planId, planName, summary){
 }
 
 function showTickets(tcName, planId, planName){ 
-	var url = baseLocation+'/query?description=~'+tcName+'?planId='+planId; 
+	var url = baseLocation+'/query?testcaseid=~'+tcName+'&planid='+planId; 
 	window.location = url;
 }
 
@@ -714,9 +714,11 @@ function hidePencil(id) {
 
 function changestate(tc, planid, path, newStatus, newStatusColor, newLabel) {
 
-    var url = baseLocation+"/teststatusupdate?id="+tc+"&planid="+planid+"&status="+newStatus+"&path="+path;
+    var url = baseLocation+"/teststatusupdate";
     
-    result = doAjaxCall(url, "GET", "");
+    var params = {id: tc, planid: planid, status: newStatus, path: path};
+    
+    result = doAjaxCall(url, "GET", params);
 
     /* Handle errors in the Ajax call */
     if (result == 'OK') {
@@ -743,8 +745,11 @@ function changestate(tc, planid, path, newStatus, newStatusColor, newLabel) {
 }
 
 function changestateOnPlan(imgNode, tc, planid, newStatus, newStatusColor, newLabel) {
-    var url = baseLocation+"/teststatusupdate?id="+tc+"&planid="+planid+"&status="+newStatus;
-    result = doAjaxCall(url, "GET", "");
+    var url = baseLocation+"/teststatusupdate";
+
+    var params = {id: tc, planid: planid, status: newStatus};
+
+    result = doAjaxCall(url, "GET", params);
     
     /*
 	Handle errors in the Ajax call
@@ -789,15 +794,18 @@ function bindTCStatusMenus() {
 						select: function( event, ui ) {
 								event.stopPropagation();
 								
-								var newParams = ui.item.attr("name").split("|");
-								var newStatus = newParams[0];
-								var newColor = newParams[1];
-								var newLabel = newParams[2];
+								var currItemName = ui.item.attr("name");
+								if (currItemName != null && currItemName.length > 0) {
+									var newParams = currItemName.split("|");
+									var newStatus = newParams[0];
+									var newColor = newParams[1];
+									var newLabel = newParams[2];
 
-								changestateOnPlan(imgNode, tcid, planid, newStatus, newColor, newLabel);
-								
-								$("#statusmenuContainer_"+tcid+" > ul").menu("destroy");
-								$("#statusmenuContainer_"+tcid).remove();
+									changestateOnPlan(imgNode, tcid, planid, newStatus, newColor, newLabel);
+									
+									$("#statusmenuContainer_"+tcid+" > ul").menu("destroy");
+									$("#statusmenuContainer_"+tcid).remove();
+								}
 							}
 					}).popup();
 					
@@ -835,14 +843,17 @@ function bindTCStatusMenus() {
 						select: function( event, ui ) {
 								event.stopPropagation();
 								
-								var newParams = ui.item.attr("name").split("|");
-								var newStatus = newParams[0];
-								var newColor = newParams[1];
-								var newLabel = newParams[2];
+								var currItemName = ui.item.attr("name");
+								if (currItemName != null && currItemName.length > 0) {
+									var newParams = currItemName.split("|");
+									var newStatus = newParams[0];
+									var newColor = newParams[1];
+									var newLabel = newParams[2];
 
-								changestate(tcid, planid, path, newStatus, newColor, newLabel);
-								
-								$("#statusSingleMenu_"+color).hide();
+									changestate(tcid, planid, path, newStatus, newColor, newLabel);
+									
+									$("#statusSingleMenu_"+color).hide();
+								}
 							}
 					}).popup();
 					
@@ -979,24 +990,30 @@ function displayNode(id, show, mode) {
 }
 
 function doAjaxCall(url, method, params) {
+	var responseText = "ERROR";
+
     try {
-        if (window.XMLHttpRequest) {
-            /* code for IE7+, Firefox, Chrome, Opera, Safari */
-             xmlhttp = new XMLHttpRequest();
-        } else {
-            /* code for IE6, IE5 */
-            xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
-        }
-        
-        xmlhttp.open(method, url, false);
-        
+		headers = {};
         if (method == "POST") {
-            xmlhttp.setRequestHeader("Content-type", "application/x-www-form-urlencoded");
-            params = "__FORM_TOKEN="+getCookie('trac_form_token')+"&"+params;
+            headers = {"Content-type": "application/x-www-form-urlencoded"};
+            params["__FORM_TOKEN"] = getCookie('trac_form_token');
         }
+
+        $.ajax({
+          async: false,
+          type: method,
+          url: url,
+          data: params,
+          dataType: "text",
+          headers: headers,
+          success: function(data) {
+              responseText = data;
+            },
+          error: function() {
+              responseText = 'ERROR';
+			}
+        });
         
-        xmlhttp.send(params);
-        responseText = xmlhttp.responseText;
     } catch (e) {
         responseText = 'ERROR';
     }
@@ -1020,10 +1037,14 @@ function sendUpdate(realm, name) {
    	var inputField = document.getElementById("custom_field_"+name);
 	var value = inputField.value;
     
-    params = "realm="+realm+"&key="+objKey+"&props="+objProps+"&name="+name+"&value="+encodeURIComponent(value);
-    var url = baseLocation+"/propertyupdate?" + params;
+    var url = baseLocation+"/propertyupdate";
+
+    /*
+     * var params = {realm: realm, key: objKey, props: objProps, name: name, value: encodeURIComponent(value)};
+     */
+    var params = {realm: realm, key: objKey, props: objProps, name: name, value: value};
     
-    result = doAjaxCall(url, "GET", "");
+    result = doAjaxCall(url, "GET", params);
 
     /*
 	Handle errors in the Ajax call
